Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserAbstractModel.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserAbstractModel.cpp	(revision 86569)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserAbstractModel.cpp	(revision 86570)
@@ -637,5 +637,5 @@
 
 void UIChooserAbstractModel::sltCloudMachineRegistered(const QString &strProviderShortName, const QString &strProfileName,
-                                                       const QUuid &uId, const bool fRegistered)
+                                                       const QUuid &uMachineId, const bool fRegistered)
 {
     /* Search for profile node: */
@@ -651,5 +651,5 @@
     {
         /* Remove machine-items with passed id: */
-        pProfileNode->removeAllNodes(uId);
+        pProfileNode->removeAllNodes(uMachineId);
 
         /* If there are no items left: */
@@ -666,5 +666,5 @@
     {
         /* Add new machine-item: */
-        const CCloudMachine comMachine = cloudMachineById(strProviderShortName, strProfileName, uId);
+        const CCloudMachine comMachine = cloudMachineById(strProviderShortName, strProfileName, uMachineId);
         addCloudMachineIntoTheTree(strProfileNodeName, comMachine, true /* make it visible */);
 
@@ -689,5 +689,5 @@
 }
 
-void UIChooserAbstractModel::sltHandleCloudProviderUninstall(const QUuid &uId)
+void UIChooserAbstractModel::sltHandleCloudProviderUninstall(const QUuid &uProviderId)
 {
     /* Search for top-level provider node: */
@@ -702,5 +702,5 @@
         const QUuid uIteratedId = pGroupNode->property("id").toUuid();
         AssertReturnVoid(!uIteratedId.isNull());
-        if (uIteratedId != uId)
+        if (uIteratedId != uProviderId)
             continue;
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserAbstractModel.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserAbstractModel.h	(revision 86569)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserAbstractModel.h	(revision 86570)
@@ -149,11 +149,11 @@
           * @param  strProfileName        Brings profile name. */
         virtual void sltCloudMachineRegistered(const QString &strProviderShortName, const QString &strProfileName,
-                                               const QUuid &uId, const bool fRegistered);
+                                               const QUuid &uMachineId, const bool fRegistered);
         /** Handles session @a enmState change for machine with certain @a uMachineId. */
         virtual void sltSessionStateChanged(const QUuid &uMachineId, const KSessionState enmState);
         /** Handles snapshot change for machine/snapshot with certain @a uMachineId / @a uSnapshotId. */
         virtual void sltSnapshotChanged(const QUuid &uMachineId, const QUuid &uSnapshotId);
-        /** Handles event about cloud provider with @a uId being uninstalled. */
-        virtual void sltHandleCloudProviderUninstall(const QUuid &uId);
+        /** Handles event about cloud provider with @a uProviderId being uninstalled. */
+        virtual void sltHandleCloudProviderUninstall(const QUuid &uProviderId);
     /** @} */
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserModel.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserModel.cpp	(revision 86569)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserModel.cpp	(revision 86570)
@@ -1079,12 +1079,12 @@
 }
 
-void UIChooserModel::sltLocalMachineRegistered(const QUuid &uId, const bool fRegistered)
-{
-    /* Existing VM unregistered => make sure no item with passed uId is selected: */
+void UIChooserModel::sltLocalMachineRegistered(const QUuid &uMachineId, const bool fRegistered)
+{
+    /* Existing VM unregistered => make sure no item with passed uMachineId is selected: */
     if (!fRegistered)
-        makeSureNoItemWithCertainIdSelected(uId);
+        makeSureNoItemWithCertainIdSelected(uMachineId);
 
     /* Call to base-class: */
-    UIChooserAbstractModel::sltLocalMachineRegistered(uId, fRegistered);
+    UIChooserAbstractModel::sltLocalMachineRegistered(uMachineId, fRegistered);
 
     /* Existing VM unregistered? */
@@ -1098,10 +1098,10 @@
     {
         /* Should we show this VM? */
-        if (gEDataManager->showMachineInVirtualBoxManagerChooser(uId))
+        if (gEDataManager->showMachineInVirtualBoxManagerChooser(uMachineId))
         {
             /* Rebuild tree for main root: */
             buildTreeForMainRoot(false /* preserve selection */);
             /* Select newly added item: */
-            setSelectedItem(root()->searchForItem(uId.toString(),
+            setSelectedItem(root()->searchForItem(uMachineId.toString(),
                                                   UIChooserItemSearchFlag_Machine |
                                                   UIChooserItemSearchFlag_ExactId));
@@ -1111,12 +1111,12 @@
 
 void UIChooserModel::sltCloudMachineRegistered(const QString &strProviderShortName, const QString &strProfileName,
-                                               const QUuid &uId, const bool fRegistered)
-{
-    /* Existing VM unregistered => make sure no item with passed uId is selected: */
+                                               const QUuid &uMachineId, const bool fRegistered)
+{
+    /* Existing VM unregistered => make sure no item with passed uMachineId is selected: */
     if (!fRegistered)
-        makeSureNoItemWithCertainIdSelected(uId);
+        makeSureNoItemWithCertainIdSelected(uMachineId);
 
     /* Call to base-class: */
-    UIChooserAbstractModel::sltCloudMachineRegistered(strProviderShortName, strProfileName, uId, fRegistered);
+    UIChooserAbstractModel::sltCloudMachineRegistered(strProviderShortName, strProfileName, uMachineId, fRegistered);
 
     /* Existing VM unregistered? */
@@ -1132,5 +1132,5 @@
         buildTreeForMainRoot(false /* preserve selection */);
         /* Select newly added item: */
-        setSelectedItem(root()->searchForItem(uId.toString(),
+        setSelectedItem(root()->searchForItem(uMachineId.toString(),
                                               UIChooserItemSearchFlag_Machine |
                                               UIChooserItemSearchFlag_ExactId));
@@ -1138,5 +1138,5 @@
 }
 
-void UIChooserModel::sltHandleCloudProviderUninstall(const QUuid &uId)
+void UIChooserModel::sltHandleCloudProviderUninstall(const QUuid &uProviderId)
 {
     /* Search for selected cloud machine items: */
@@ -1154,5 +1154,5 @@
 
     /* Call to base-class: */
-    UIChooserAbstractModel::sltHandleCloudProviderUninstall(uId);
+    UIChooserAbstractModel::sltHandleCloudProviderUninstall(uProviderId);
 
     /* Notify about selection invalidated: */
@@ -1160,16 +1160,16 @@
 }
 
-void UIChooserModel::sltReloadMachine(const QUuid &uId)
+void UIChooserModel::sltReloadMachine(const QUuid &uMachineId)
 {
     /* Call to base-class: */
-    UIChooserAbstractModel::sltReloadMachine(uId);
+    UIChooserAbstractModel::sltReloadMachine(uMachineId);
 
     /* Should we show this VM? */
-    if (gEDataManager->showMachineInVirtualBoxManagerChooser(uId))
+    if (gEDataManager->showMachineInVirtualBoxManagerChooser(uMachineId))
     {
         /* Rebuild tree for main root: */
         buildTreeForMainRoot(false /* preserve selection */);
         /* Select newly added item: */
-        setSelectedItem(root()->searchForItem(uId.toString(),
+        setSelectedItem(root()->searchForItem(uMachineId.toString(),
                                               UIChooserItemSearchFlag_Machine |
                                               UIChooserItemSearchFlag_ExactId));
Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserModel.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserModel.h	(revision 86569)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/chooser/UIChooserModel.h	(revision 86570)
@@ -261,19 +261,19 @@
     /** @name Main event handling stuff.
       * @{ */
-        /** Handles local machine registering/unregistering for machine with certain @a uId. */
-        virtual void sltLocalMachineRegistered(const QUuid &uId, const bool fRegistered) /* override */;
-        /** Handles cloud machine registering/unregistering for machine with certain @a uId.
+        /** Handles local machine registering/unregistering for machine with certain @a uMachineId. */
+        virtual void sltLocalMachineRegistered(const QUuid &uMachineId, const bool fRegistered) /* override */;
+        /** Handles cloud machine registering/unregistering for machine with certain @a uMachineId.
           * @param  strProviderShortName  Brings provider short name.
           * @param  strProfileName        Brings profile name. */
         virtual void sltCloudMachineRegistered(const QString &strProviderShortName, const QString &strProfileName,
-                                               const QUuid &uId, const bool fRegistered);
-        /** Handles event about cloud provider with @a uId being uninstalled. */
-        virtual void sltHandleCloudProviderUninstall(const QUuid &uId);
+                                               const QUuid &uMachineId, const bool fRegistered);
+        /** Handles event about cloud provider with @a uProviderId being uninstalled. */
+        virtual void sltHandleCloudProviderUninstall(const QUuid &uProviderId);
     /** @} */
 
     /** @name Children stuff.
       * @{ */
-        /** Handles reload machine with certain @a uId request. */
-        virtual void sltReloadMachine(const QUuid &uId) /* override */;
+        /** Handles reload machine with certain @a uMachineId request. */
+        virtual void sltReloadMachine(const QUuid &uMachineId) /* override */;
     /** @} */
 
